package com.persagy.framework.ems.data.pojo.hbase;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.persagy.framework.ems.data.core.annotation.*;
import com.persagy.framework.ems.data.core.enumeration.Schema;
import com.persagy.framework.ems.data.core.enumeration.TimePatitionType;
import com.persagy.framework.ems.data.mvc.pojo.BusinessObject;
import lombok.Data;

import java.util.Date;

@Entity(name = "IndicatorComputeLog")
@Table(name = "indicator_compute_log", comment = "运行诊断计算发数日志", schema = Schema.UDM,
		indexes = {
				@Index(columns = {"project", "obj_id", "code", "log_time"}),
				@Index(columns = {"project", "obj_id", "code","log_type","log_time"}),
				@Index(columns = {"project", "obj_id", "code","log_type","data_time"})
		})
@Dimension
@TimePatition(column = "data_time", type = TimePatitionType.month)
@Data
public class IndicatorComputeLog extends BusinessObject {

	private static final long serialVersionUID = 9123470427203487460L;

	@Column(order = 10, name = "project", length = 50, nullable = false, comment = "项目/建筑id")
	@JsonProperty("project")
	private String project;

	@Column(order = 20, name = "obj_id", length = 50, nullable = true, comment = "能耗模型id")
	@JsonProperty("objId")
	private String objId;

	@Column(order = 30, name = "code", length = 50, nullable = true, comment = "分项id")
	@JsonProperty("code")
	private String code;

	@Column(order = 40, name = "log_time", length = 0, nullable = false, comment = "数据时间")
	@JsonProperty("logTime")
	private Date logTime;


	@Column(order = 50, name = "log_type", length = 1, nullable = false, comment = "0计算日志，1发数日志")
	@JsonProperty("logType")
	private Long logType;


	@Column(order = 60, name = "data_time", length = 0, nullable = false, comment = "数据时间")
	@JsonProperty("dataTime")
	private Date dataTime;

	@Column(order = 70, name = "compute_round", length = 128, nullable = true, comment = "计算论次")
	@JsonProperty("computeRound")
	private Long computeRound;

	@Column(order = 80, name = "log_info", length = 128, nullable = false, comment = "日志详情")
	@JsonProperty("logInfo")
	private String logInfo;
}
